/*
 * This file is part of the LinuxBIOS project.
 *
 * Copyright (C)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef RAMINIT_H
#define RAMINIT_H

/* The ALi Aladdin-Pro II supports up to four DIMMs with 2 rows each. */
#define DIMM_SOCKETS 4
#define DIMM_ROWS 2

enum E_CR_MROW_MASKS {
  e_MA_ASSERTATION      = 0x80000000,
  e_PAGE_HIT_WAIT_STATE = 0x40000000,
  e_EDO_SR_SDR_CL       = 0x20000000,
  e_DRAM_TYPE           = 0x18000000,
  e_1ST_ROW             = 0x06000000,
  e_2ND_ROW             = 0x01800000,
  e_ROW_SIZE            = 0x00700000,
  e_COLUMN_ADDRESS_TYPE = 0x000F0000,
  e_EDO_ASR_SDR_CSQ     = 0x00008000,
  e_EDO_RAH_SDR_BANK    = 0x00006000,
  e_EDO_ASC_SDR_BANK    = 0x00001800,
  e_EDO_RCAS            = 0x00000600,
  e_EDO_WCAS            = 0x00000180,
  e_EDO_CP_SDR_REG      = 0x00000040,
  e_EDO_CSH_SDR_RCD_RP  = 0x00000030,
  e_EDO_RAS_SDR_BANK    = 0x0000000C,
  e_EDO_RP_SDR_BANK     = 0x00000003
};

enum E_CR_MCMD_MASKS {
  e_MEMORY_PROTECTION   = 0xC0000000,
  e_MWB_ALLOCATION      = 0x30000000,
  e_REF_QUEUE_DEPTH     = 0x08000000,
  e_REF_START_CONTROL   = 0x07000000,
  e_AF_START_CONTROL    = 0x00C00000,
  e_DRAM_REFRESH_ENV    = 0x00200000,
  e_EDO_DETECT_MODE     = 0x00100000,
  e_DRAM_REFRESH_ENABLE = 0x00080000,
  e_DRAM_REF_CASL_RASL  = 0x00040000,
  e_DRAM_REF_RAS        = 0x00030000,
  e_DRAM_REF_RP         = 0x0000C000,
  e_DRAM_REFRESH_CYCLE  = 0x00003FFF,
};

enum E_DRAM_TYPE {
  e_FPM  = 0x00000000,
  e_EDO  = 0x08000000,
  e_SDR  = 0x10000000,
};

enum E_DRAM_ROW_SIZE {
  e_4MB   = 0x00000000,
  e_8MB   = 0x00100000,
  e_16MB  = 0x00200000,
  e_32MB  = 0x00300000,
  e_64MB  = 0x00400000,
  e_128MB = 0x00500000,
  e_256MB = 0x00600000
};

enum E_DRAM_CA {
  e_8BIT         = 0x00000000,
  e_9BIT         = 0x00010000,
  e_10BIT        = 0x00020000,
  e_11BIT        = 0x00030000,
  e_12BIT        = 0x00040000,
  e_USER_DEFINED = 0x000F0000
};

uint32_t au32_DRAM[DIMM_SOCKETS];

/* The ALi Aladdin-Pro II memory controller has one channel only. */
struct mem_controller {
	device_t d0;
	uint16_t channel0[DIMM_SOCKETS];
};

#endif				/* RAMINIT_H */
